@@ -2,7 +2,7 @@
 
 __author__ = """Bradley Axen"""
 __email__ = "baxen@squareup.com"
-__version__ = "0.7.0"
+__version__ = "0.7.1"
 
 
 from blocks.core import (
@@ -11,5 +11,7 @@ from blocks.core import (
     partitioned,
     divide,
     place,
+    pickle,
+    unpickle,
 )  # NOQA
 from blocks.dfio import read_df, write_df  # NOQA
